# Solow Library
A Solow simulator to help understand the basics of the model

### Installation
```
pip install solow-sim
```

### Get started
To start experimenting

```Python
from solow_library import user_interface
user_interface
```
Then, run the python file and follow the instructions.
To play around by yourself,

```Python
from solow_library import solow
```